pub struct createEd25519KeyCall {
pub salt: FixedBytes<32>,
}Expand description
Generates an Ed25519 key pair from a deterministic salt.
Returns (publicKey, privateKey) as 32-byte values.
Function with signature createEd25519Key(bytes32) and selector 0x1ef3f27a.
function createEd25519Key(bytes32 salt) external pure returns (bytes32 publicKey, bytes32 privateKey);Fields
salt: FixedBytes<32>Trait Implementations
Sourceimpl CheatcodeDef for createEd25519KeyCall
impl CheatcodeDef for createEd25519KeyCall
Sourceimpl Clone for createEd25519KeyCall
impl Clone for createEd25519KeyCall
Sourcefn clone(&self) -> createEd25519KeyCall
fn clone(&self) -> createEd25519KeyCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for createEd25519KeyCall
impl Debug for createEd25519KeyCall
Sourceimpl JsonAbiExt for createEd25519KeyCall
impl JsonAbiExt for createEd25519KeyCall
Sourceimpl SolCall for createEd25519KeyCall
impl SolCall for createEd25519KeyCall
Sourcetype Parameters<'a> = (FixedBytes<32>,)
type Parameters<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<createEd25519KeyCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<createEd25519KeyCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = createEd25519KeyReturn
type Return = createEd25519KeyReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (FixedBytes<32>, FixedBytes<32>)
type ReturnTuple<'a> = (FixedBytes<32>, FixedBytes<32>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<createEd25519KeyCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<createEd25519KeyCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.