pub struct deriveKey_2Return {
pub privateKey: U256,
}Expand description
Derive a private key from a provided mnemonic string (or mnemonic file path) in the specified language
at the derivation path m/44'/60'/0'/0/{index}.
Container type for the return parameters of the deriveKey(string,uint32,string) function.
Fields
privateKey: U256Trait Implementations
Sourceimpl Clone for deriveKey_2Return
impl Clone for deriveKey_2Return