pub struct executeTransactionReturn {
pub _0: Bytes,
}Expand description
Executes an RLP-encoded signed transaction with full EVM semantics (like --isolate mode).
The transaction is decoded from EIP-2718 format (type byte prefix + RLP payload) or legacy RLP.
Returns the execution output bytes.
This cheatcode is not allowed in forge script contexts.
Container type for the return parameters of the executeTransaction(bytes) function.
Fields
_0: BytesTrait Implementations
Sourceimpl Clone for executeTransactionReturn
impl Clone for executeTransactionReturn
Sourcefn clone(&self) -> executeTransactionReturn
fn clone(&self) -> executeTransactionReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for executeTransactionReturn
impl RefUnwindSafe for executeTransactionReturn
impl Send for executeTransactionReturn
impl Sync for executeTransactionReturn
impl Unpin for executeTransactionReturn
impl UnsafeUnpin for executeTransactionReturn
impl UnwindSafe for executeTransactionReturn