pub struct expectDelegateCallReturn {}Expand description
Expects a delegate call to an address with the specified calldata.
Calldata can either be a strict or a partial match.
Container type for the return parameters of the expectDelegateCall(address,bytes) function.
Implementations
Sourceimpl expectDelegateCallReturn
impl expectDelegateCallReturn
fn _tokenize(&self) -> <expectDelegateCallCall as SolCall>::ReturnToken<'_>