pub struct expectEmit_0Call {
pub checkTopic1: bool,
pub checkTopic2: bool,
pub checkTopic3: bool,
pub checkData: bool,
}Expand description
Prepare an expected log with (bool checkTopic1, bool checkTopic2, bool checkTopic3, bool checkData.).
Call this function, then emit an event, then call a function. Internally after the call, we check if
logs were emitted in the expected order with the expected topics and data (as specified by the booleans).
Must be placed immediately before the call you want to assert on. If the next call reverts and the
revert is caught by the caller (low-level call or try/catch), the expectation remains active and may
be satisfied by a log emitted from a later call.
Function with signature expectEmit(bool,bool,bool,bool) and selector 0x491cc7c2.
function expectEmit(bool checkTopic1, bool checkTopic2, bool checkTopic3, bool checkData) external;Fields
checkTopic1: boolcheckTopic2: boolcheckTopic3: boolcheckData: boolTrait Implementations
Sourceimpl CheatcodeDef for expectEmit_0Call
impl CheatcodeDef for expectEmit_0Call
Sourceimpl Clone for expectEmit_0Call
impl Clone for expectEmit_0Call
Sourcefn clone(&self) -> expectEmit_0Call
fn clone(&self) -> expectEmit_0Call
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for expectEmit_0Call
impl Debug for expectEmit_0Call
Sourceimpl JsonAbiExt for expectEmit_0Call
impl JsonAbiExt for expectEmit_0Call
Sourceimpl SolCall for expectEmit_0Call
impl SolCall for expectEmit_0Call
Sourceconst SIGNATURE: &'static str = "expectEmit(bool,bool,bool,bool)"
const SIGNATURE: &'static str = "expectEmit(bool,bool,bool,bool)"
Sourcetype Parameters<'a> = (Bool, Bool, Bool, Bool)
type Parameters<'a> = (Bool, Bool, Bool, Bool)
Sourcetype Token<'a> = <<expectEmit_0Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<expectEmit_0Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
Sourcetype Return = expectEmit_0Return
type Return = expectEmit_0Return
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
Sourcetype ReturnToken<'a> = <<expectEmit_0Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<expectEmit_0Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ