pub struct expectEmit_0Return {}Expand description
Prepare an expected log with (bool checkTopic1, bool checkTopic2, bool checkTopic3, bool checkData.).
Call this function, then emit an event, then call a function. Internally after the call, we check if
logs were emitted in the expected order with the expected topics and data (as specified by the booleans).
Must be placed immediately before the call you want to assert on. If the next call reverts and the
revert is caught by the caller (low-level call or try/catch), the expectation remains active and may
be satisfied by a log emitted from a later call.
Container type for the return parameters of the expectEmit(bool,bool,bool,bool) function.
Implementations
Sourceimpl expectEmit_0Return
impl expectEmit_0Return
fn _tokenize(&self) -> <expectEmit_0Call as SolCall>::ReturnToken<'_>