pub struct expectEmit_2Call;Expand description
Prepare an expected log with all topic and data checks enabled.
Call this function, then emit an event, then call a function. Internally after the call, we check if
logs were emitted in the expected order with the expected topics and data.
Must be placed immediately before the call you want to assert on. If the next call reverts and the
revert is caught by the caller (low-level call or try/catch), the expectation remains active and may
be satisfied by a log emitted from a later call.
Function with signature expectEmit() and selector 0x440ed10d.
function expectEmit() external;Trait Implementations
Sourceimpl CheatcodeDef for expectEmit_2Call
impl CheatcodeDef for expectEmit_2Call
Sourceimpl Clone for expectEmit_2Call
impl Clone for expectEmit_2Call
Sourcefn clone(&self) -> expectEmit_2Call
fn clone(&self) -> expectEmit_2Call
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for expectEmit_2Call
impl Debug for expectEmit_2Call
Sourceimpl JsonAbiExt for expectEmit_2Call
impl JsonAbiExt for expectEmit_2Call
Sourceimpl SolCall for expectEmit_2Call
impl SolCall for expectEmit_2Call
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
Sourcetype Token<'a> = <<expectEmit_2Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<expectEmit_2Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
Sourcetype Return = expectEmit_2Return
type Return = expectEmit_2Return
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
Sourcetype ReturnToken<'a> = <<expectEmit_2Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<expectEmit_2Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ