pub struct expectEmit_2Return {}Expand description
Prepare an expected log with all topic and data checks enabled.
Call this function, then emit an event, then call a function. Internally after the call, we check if
logs were emitted in the expected order with the expected topics and data.
Must be placed immediately before the call you want to assert on. If the next call reverts and the
revert is caught by the caller (low-level call or try/catch), the expectation remains active and may
be satisfied by a log emitted from a later call.
Container type for the return parameters of the expectEmit() function.
Implementations
Sourceimpl expectEmit_2Return
impl expectEmit_2Return
fn _tokenize(&self) -> <expectEmit_2Call as SolCall>::ReturnToken<'_>