pub struct expectRevert_9Return {}Expand description
Expects a count number of reverts from the upcoming calls from the reverter address.
See expectRevert(address) for reverter matching semantics.
Container type for the return parameters of the expectRevert(address,uint64) function.
Implementations
Sourceimpl expectRevert_9Return
impl expectRevert_9Return
fn _tokenize(&self) -> <expectRevert_9Call as SolCall>::ReturnToken<'_>