pub struct ffiStringReturn {
pub result: String,
}Expand description
Performs a foreign function call via the terminal and returns the output as a string.
Container type for the return parameters of the ffiString(string[]) function.
Fields
result: StringTrait Implementations
Sourceimpl Clone for ffiStringReturn
impl Clone for ffiStringReturn
Sourcefn clone(&self) -> ffiStringReturn
fn clone(&self) -> ffiStringReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ffiStringReturn
impl RefUnwindSafe for ffiStringReturn
impl Send for ffiStringReturn
impl Sync for ffiStringReturn
impl Unpin for ffiStringReturn
impl UnsafeUnpin for ffiStringReturn
impl UnwindSafe for ffiStringReturn