pub struct parseJsonAddress_0Return {
pub _0: Address,
}Expand description
Parses a string of JSON data at key and coerces it to address.
Container type for the return parameters of the parseJsonAddress(string,string) function.
Fields
_0: AddressTrait Implementations
Sourceimpl Clone for parseJsonAddress_0Return
impl Clone for parseJsonAddress_0Return
Sourcefn clone(&self) -> parseJsonAddress_0Return
fn clone(&self) -> parseJsonAddress_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseJsonAddress_0Return
impl RefUnwindSafe for parseJsonAddress_0Return
impl Send for parseJsonAddress_0Return
impl Sync for parseJsonAddress_0Return
impl Unpin for parseJsonAddress_0Return
impl UnsafeUnpin for parseJsonAddress_0Return
impl UnwindSafe for parseJsonAddress_0Return