pub struct parseJsonBool_1Return {
pub _0: bool,
}Expand description
Parses a string of JSON data at key and coerces it to bool, or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseJsonBool(string,string,bool) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for parseJsonBool_1Return
impl Clone for parseJsonBool_1Return
Sourcefn clone(&self) -> parseJsonBool_1Return
fn clone(&self) -> parseJsonBool_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseJsonBool_1Return
impl RefUnwindSafe for parseJsonBool_1Return
impl Send for parseJsonBool_1Return
impl Sync for parseJsonBool_1Return
impl Unpin for parseJsonBool_1Return
impl UnsafeUnpin for parseJsonBool_1Return
impl UnwindSafe for parseJsonBool_1Return