pub struct parseJsonBytes_1Return {
pub _0: Bytes,
}Expand description
Parses a string of JSON data at key and coerces it to bytes, or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseJsonBytes(string,string,bytes) function.
Fields
_0: BytesTrait Implementations
Sourceimpl Clone for parseJsonBytes_1Return
impl Clone for parseJsonBytes_1Return
Sourcefn clone(&self) -> parseJsonBytes_1Return
fn clone(&self) -> parseJsonBytes_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for parseJsonBytes_1Return
impl RefUnwindSafe for parseJsonBytes_1Return
impl Send for parseJsonBytes_1Return
impl Sync for parseJsonBytes_1Return
impl Unpin for parseJsonBytes_1Return
impl UnsafeUnpin for parseJsonBytes_1Return
impl UnwindSafe for parseJsonBytes_1Return