pub struct parseTomlAddressArray_0Return {
pub _0: Vec<Address>,
}Expand description
Parses a string of TOML data at key and coerces it to address[].
Container type for the return parameters of the parseTomlAddressArray(string,string) function.
Fields
_0: Vec<Address>Trait Implementations