pub struct parseTomlBool_1Return {
pub _0: bool,
}Expand description
Parses a string of TOML data at key and coerces it to bool, or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseTomlBool(string,string,bool) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for parseTomlBool_1Return
impl Clone for parseTomlBool_1Return
Sourcefn clone(&self) -> parseTomlBool_1Return
fn clone(&self) -> parseTomlBool_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlBool_1Return
impl RefUnwindSafe for parseTomlBool_1Return
impl Send for parseTomlBool_1Return
impl Sync for parseTomlBool_1Return
impl Unpin for parseTomlBool_1Return
impl UnsafeUnpin for parseTomlBool_1Return
impl UnwindSafe for parseTomlBool_1Return