pub struct parseTomlBytesArray_0Return {
pub _0: Vec<Bytes>,
}Expand description
Parses a string of TOML data at key and coerces it to bytes[].
Container type for the return parameters of the parseTomlBytesArray(string,string) function.
Fields
_0: Vec<Bytes>Trait Implementations
Sourceimpl Clone for parseTomlBytesArray_0Return
impl Clone for parseTomlBytesArray_0Return
Sourcefn clone(&self) -> parseTomlBytesArray_0Return
fn clone(&self) -> parseTomlBytesArray_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlBytesArray_0Return
impl RefUnwindSafe for parseTomlBytesArray_0Return
impl Send for parseTomlBytesArray_0Return
impl Sync for parseTomlBytesArray_0Return
impl Unpin for parseTomlBytesArray_0Return
impl UnsafeUnpin for parseTomlBytesArray_0Return
impl UnwindSafe for parseTomlBytesArray_0Return