pub struct parseTomlInt_0Return {
pub _0: I256,
}Expand description
Parses a string of TOML data at key and coerces it to int256.
Container type for the return parameters of the parseTomlInt(string,string) function.
Fields
_0: I256Trait Implementations
Sourceimpl Clone for parseTomlInt_0Return
impl Clone for parseTomlInt_0Return
Sourcefn clone(&self) -> parseTomlInt_0Return
fn clone(&self) -> parseTomlInt_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlInt_0Return
impl RefUnwindSafe for parseTomlInt_0Return
impl Send for parseTomlInt_0Return
impl Sync for parseTomlInt_0Return
impl Unpin for parseTomlInt_0Return
impl UnsafeUnpin for parseTomlInt_0Return
impl UnwindSafe for parseTomlInt_0Return