pub struct parseTomlStringArray_1Return {
pub _0: Vec<String>,
}Expand description
Parses a string of TOML data at key and coerces it to string[], or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseTomlStringArray(string,string,string[]) function.
Fields
_0: Vec<String>Trait Implementations
Sourceimpl Clone for parseTomlStringArray_1Return
impl Clone for parseTomlStringArray_1Return
Sourcefn clone(&self) -> parseTomlStringArray_1Return
fn clone(&self) -> parseTomlStringArray_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlStringArray_1Return
impl RefUnwindSafe for parseTomlStringArray_1Return
impl Send for parseTomlStringArray_1Return
impl Sync for parseTomlStringArray_1Return
impl Unpin for parseTomlStringArray_1Return
impl UnsafeUnpin for parseTomlStringArray_1Return
impl UnwindSafe for parseTomlStringArray_1Return