pub struct parseTomlUintArray_1Return {
pub _0: Vec<U256>,
}Expand description
Parses a string of TOML data at key and coerces it to uint256[], or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseTomlUintArray(string,string,uint256[]) function.
Fields
_0: Vec<U256>Trait Implementations
Sourceimpl Clone for parseTomlUintArray_1Return
impl Clone for parseTomlUintArray_1Return
Sourcefn clone(&self) -> parseTomlUintArray_1Return
fn clone(&self) -> parseTomlUintArray_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlUintArray_1Return
impl RefUnwindSafe for parseTomlUintArray_1Return
impl Send for parseTomlUintArray_1Return
impl Sync for parseTomlUintArray_1Return
impl Unpin for parseTomlUintArray_1Return
impl UnsafeUnpin for parseTomlUintArray_1Return
impl UnwindSafe for parseTomlUintArray_1Return