pub struct randomBytesReturn {
pub _0: Bytes,
}Expand description
Returns a random byte array value of the given length.
Container type for the return parameters of the randomBytes(uint256) function.
Fields
_0: BytesTrait Implementations
Sourceimpl Clone for randomBytesReturn
impl Clone for randomBytesReturn