pub struct rpcJson_1Call {
pub urlOrAlias: String,
pub method: String,
pub params: String,
}Expand description
Performs an Ethereum JSON-RPC request to the given endpoint and returns the JSON result.
Function with signature rpcJson(string,string,string) and selector 0x273b74f8.
function rpcJson(string calldata urlOrAlias, string calldata method, string calldata params) external returns (string memory data);Fields
urlOrAlias: Stringmethod: Stringparams: StringTrait Implementations
Sourceimpl CheatcodeDef for rpcJson_1Call
impl CheatcodeDef for rpcJson_1Call
Sourceimpl Clone for rpcJson_1Call
impl Clone for rpcJson_1Call
Sourcefn clone(&self) -> rpcJson_1Call
fn clone(&self) -> rpcJson_1Call
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for rpcJson_1Call
impl Debug for rpcJson_1Call
Sourceimpl JsonAbiExt for rpcJson_1Call
impl JsonAbiExt for rpcJson_1Call
Sourceimpl SolCall for rpcJson_1Call
impl SolCall for rpcJson_1Call
Sourcetype Parameters<'a> = (String, String, String)
type Parameters<'a> = (String, String, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<rpcJson_1Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<rpcJson_1Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (String,)
type ReturnTuple<'a> = (String,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<rpcJson_1Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<rpcJson_1Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.