pub struct setTip20LogoURICall {
pub token: Address,
pub newLogoURI: String,
}Expand description
Sets a TIP-20 token’s logo URI directly in storage.
This bypasses the token admin check, but still validates the URI against T5 constraints.
Function with signature setTip20LogoURI(address,string) and selector 0xb452dc23.
function setTip20LogoURI(address token, string calldata newLogoURI) external;Fields
token: AddressnewLogoURI: StringTrait Implementations
Sourceimpl CheatcodeDef for setTip20LogoURICall
impl CheatcodeDef for setTip20LogoURICall
Sourceimpl Clone for setTip20LogoURICall
impl Clone for setTip20LogoURICall
Sourcefn clone(&self) -> setTip20LogoURICall
fn clone(&self) -> setTip20LogoURICall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for setTip20LogoURICall
impl Debug for setTip20LogoURICall
Sourceimpl JsonAbiExt for setTip20LogoURICall
impl JsonAbiExt for setTip20LogoURICall
Sourceimpl SolCall for setTip20LogoURICall
impl SolCall for setTip20LogoURICall
Sourceconst SIGNATURE: &'static str = "setTip20LogoURI(address,string)"
const SIGNATURE: &'static str = "setTip20LogoURI(address,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, String)
type Parameters<'a> = (Address, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<setTip20LogoURICall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<setTip20LogoURICall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = setTip20LogoURIReturn
type Return = setTip20LogoURIReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<setTip20LogoURICall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<setTip20LogoURICall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.