pub struct signAndAttachDelegation_0Return {
pub signedDelegation: <SignedDelegation as SolType>::RustType,
}Expand description
Sign an EIP-7702 authorization and designate the next call as an EIP-7702 transaction
Container type for the return parameters of the signAndAttachDelegation(address,uint256) function.
Fields
signedDelegation: <SignedDelegation as SolType>::RustTypeTrait Implementations