pub struct verifyEd25519Call {
pub signature: Bytes,
pub namespace: Bytes,
pub message: Bytes,
pub publicKey: FixedBytes<32>,
}Expand description
Verifies an Ed25519 signature over namespace || message.
Returns true if signature is valid, false otherwise.
Function with signature verifyEd25519(bytes,bytes,bytes,bytes32) and selector 0xd08c2888.
function verifyEd25519(bytes calldata signature, bytes calldata namespace, bytes calldata message, bytes32 publicKey) external pure returns (bool valid);Fields
signature: Bytesnamespace: Bytesmessage: BytespublicKey: FixedBytes<32>Trait Implementations
Sourceimpl CheatcodeDef for verifyEd25519Call
impl CheatcodeDef for verifyEd25519Call
Sourceimpl Clone for verifyEd25519Call
impl Clone for verifyEd25519Call
Sourcefn clone(&self) -> verifyEd25519Call
fn clone(&self) -> verifyEd25519Call
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for verifyEd25519Call
impl Debug for verifyEd25519Call
Sourceimpl JsonAbiExt for verifyEd25519Call
impl JsonAbiExt for verifyEd25519Call
Sourceimpl SolCall for verifyEd25519Call
impl SolCall for verifyEd25519Call
Sourceconst SIGNATURE: &'static str = "verifyEd25519(bytes,bytes,bytes,bytes32)"
const SIGNATURE: &'static str = "verifyEd25519(bytes,bytes,bytes,bytes32)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Bytes, Bytes, Bytes, FixedBytes<32>)
type Parameters<'a> = (Bytes, Bytes, Bytes, FixedBytes<32>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<verifyEd25519Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<verifyEd25519Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<verifyEd25519Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<verifyEd25519Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.